<?php

namespace App\Http\Controllers\Admin;

use Carbon;
use App\Classes\Reply;
// use Illuminate\Http\Request;
use App\Models\Admin;
use App\Exports\AdminExport;
use Illuminate\Support\Facades\Hash;
use App\Http\Requests\Admin\Admin\CreateRequest;
use App\Http\Requests\Admin\Admin\UpdateRequest;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\AdminBaseController;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Facades\Input; 
use Illuminate\Http\Request;
use Validator;
use Response;



class AdminController extends AdminBaseController
{
    /**
     * Constructor for the Employees
     */

    public function __construct()
    {
        parent::__construct();
        $this->pageTitle = 'Admin';
        $this->adminActive = 'active';
    }

    public $successStatus = 200;
    

    public function admin_login(Request $request){ 
      
            $user = Admin::where('email', $request->email)->first(); 
            if ($user ) {
                if (Hash::check($request->password, $user->password)) {
                    $token = $user->createToken('Laravel Password Grant Client')->accessToken; 
                    Admin::where('email',$request->email)->update([
                      'fcm_id'      => $request->fcm_id,
                      'device_id'   => $request->device_id,
                      'device_name' => $request->device_name
                  ]);  
                    return response([
                        'status'	 => True,
                        'data'       => ( $response = array_merge(['token' => $token], $user->toArray())),
                        'message'    => 'Login API'
                      ]);

                } else {
                    $response = "Password missmatch";
                    return response([
                        'status'	 => False,
                        'data'       => $response,
                        'message'    => 'Login API'
                     ]);
               }
                } else {
                    $response = "Admin does not exist. Please Contact to HR. Department!";

                    return response([
                        'status'	 => False,
                        'data'       => $response,
                        'message'    => 'Login API'
                      ]);
                   }
               }

    public function admin_logout(Request $request) {

        $token = $request->user()->token();
        $token->revoke();
        $response = 'You have been succesfully logged out!';
        return response([
          'status'	 => True,
          'data'     => $response,
          'message'  => ' Logout API'
        ]);
      }

    public function index()
    {
        return View::make('admin.admin.index', $this->data);
    }
    /**
     * @return \Illuminate\Http\JsonResponse
     * @throws \Exception
     */
    public function ajaxAdmin()
    {
        $user = admin();
        $result = Admin::select('id', 'name', 'email');
        return datatables()->eloquent($result)
            ->filter(function ($query) {
                if (request()->search['value']) {
                    $query->where('name', 'LIKE', '%' . request()->search['value'] . '%')
                        ->orWhere('email', 'LIKE', '%' . request()->search['value'] . '%');
                }
            })
            ->addColumn('edit', function ($row) use ($user) {
                if ($row->id != $user->id) {
                    return '<a  class="btn btn-sm purple"  href="' . route('admin.admin.edit', $row->id) . '" ><i class="fa fa-edit"></i> View/Edit</a>
                         &nbsp;<a href="javascript:;" onclick="del(' . $row->id . ',\'' . $row->name . '\');return false;" class="btn btn-sm red">
                         <i class="fa fa-trash"></i> Delete</a>';
                } else {
                    return '<a  class="btn btn-sm purple"  href="' . route('admin.admin.edit', $row->id) . '" ><i class="fa fa-edit"></i> View/Edit</a>
                &nbsp';
                }
            })
            ->escapeColumns(['edit', 'application_status'])
            ->make(false);
    }

    /**
     * Show the form for creating a new admin
     */
    public function create()
    {
        return View::make('admin.admin.create', $this->data);
    }

    /**
     * @param CreateRequest $request
     * @return array
     * @throws \Exception
     */
    public function store(CreateRequest $request)
    {
        try {
            $employee = Admin::create([
                'name' => $request->name,
                'email' => $request->email,
                'admin_type' => $request->admin_type,
                'password' => Hash::make($request->password),
                'last_login' => Carbon\Carbon::now('Asia/Kolkata'),
            ]);
            // dd($employee);
        } catch (\Exception $e) {
            DB::rollback();
            throw $e;
        }
        return Reply::redirect(route('admin.admin.index'), '</strong> successfully added to the Database');
    }
    /**
     * Show the form for editing the specified admin
     */
    public function edit($id)
    {
        $this->employeesActive = 'active';
        $this->admin_user = Admin::findOrFail($id);
        return View::make('admin.admin.edit', $this->data);
    }

    /**
     * Update the specified admin in storage.
     */
    public function update(UpdateRequest $request, $id)
    {
        
        $admin = Admin::findOrFail($id);
        $admin->update([
            'name' => $request->name,
            'email' => $request->email,
            'admin_type' => $request->admin_type,
            'password' => Hash::make($request->password),
        ]);
        // dd($request->all());
        return Reply::redirect(route('admin.admin.index'), '<strong>Success</strong> Updated Successfully');
    }
    /**
     * @param $id
     * @return array
     * Delete Admin  Completely
     */
    public function destroy($id)
    {
        $user = admin();
        if ($user->id == $id) {
            return Reply::error('unable to delete admin , admin is logged in');
        } else {
            Admin::destroy($id);
        }
        return Reply::success('messages.successDelete');
    }

    //export Admin List
    public function export()
    {
        $fileName = 'Admin-' . time() . '.xlsx';
        if (request()->filled('s')) {
            return (new AdminExport(request()->input('s')))->download($fileName);
        }
        return (new AdminExport)->download($fileName);
    }
}
