<?php

namespace App\Http\Controllers\front;

use App\Classes\Reply;
use App\Classes\Files;    
use Illuminate\Support\Facades\Input; 
use Illuminate\Http\Request;
use App\Events\ChangePasswordEvent;
use App\Events\HalfDayRequestToAdminEvent;
use App\Events\LeaveRequestToAdminEvent;
use App\Http\Controllers\BaseController;
use App\Http\Requests\FrontUser\ChangePasswordRequest;
use App\Http\Requests\Admin\Employee\CreateRequest;
use App\Http\Requests\FrontUser\LeaveStoreRequest;
use App\Models\Admin;
use App\Models\Bank_detail;
use App\Models\Attendance;
use App\Models\Salary;
use App\Models\SalaryDetails;
use App\Models\Award;
use App\Models\Employee;
use App\Models\Holiday;
use App\Models\Leavetype;
use App\Models\Noticeboard;
use App\Models\Employee_document;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Response;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\View;
use App\Models\Policy;

/**
 * Class DashboardController
 * @package App\Http\Controllers\front
 */
class DashboardController extends BaseController
{

    public function __construct()
    {

        parent::__construct();

        for ($m = 1; $m <= 12; $m++) {
            $month[] = date('F', mktime(0, 0, 0, $m, 1, date('Y')));
        }

        $this->months = $month;
        $this->currentMonth = date('F');

        $this->middleware(function ($request, $next) {

            $this->pageTitle = 'Dashboard';

            $this->employeeID = Auth::guard('employees')->user()->employeeID;

            $this->employee = Auth::guard('employees')->user();

            $this->leaveTypes = Attendance::leaveTypesEmployees();
            $this->leaveTypeWithoutHalfDay = Attendance::leaveTypesEmployees('half day');
            // Total leaves except
            $totalLeave = Leavetype::where('leaveType', '<>', 'half day')->sum('num_of_leave');

            $this->leaveLeft = array_sum(Attendance::absentEmployee($this->employeeID)) . '/' . $totalLeave;

            $this->employee = Employee::find(Auth::guard('employees')->user()->id);

            $this->salary = Salary::all();

            $this->holidays = Holiday::orderBy('date', 'ASC')->limit('15')->where('date','>',Carbon::now())->get();

            $this->awards = Award::select('*')->orderBy('created_at', 'desc')->get();

            $this->attendance = Attendance::where('employeeID', '=', $this->employeeID)
                ->where(function ($query) {
                    $query->where('application_status', '=', 'approved')
                        ->orWhere('application_status', '=', null)
                        ->orWhere('status', '=', 'present');
                })
                ->get();

            $this->salaryDetails = Salary::where('employeeID', '=', $this->employeeID);   

            $this->attendance_count = Attendance::attendanceCount($this->employeeID);

            $this->current_month_birthdays = Employee::currentMonthBirthday();

            return $next($request);
        });

    }

    /**
     * @return \Illuminate\Contracts\View\View
     * 
     */

    public function ajaxSalaryDetails()
    {

        $result = SalaryDetails::select('salarydetails.id','salarydetails.updatedOn','salarydetails.basicSalary','salarydetails.HRA','salarydetails.dearnessAllowance','salarydetails.specialAllowance','salarydetails.salary')
                          ->join('employees', 'salarydetails.employeeID', '=', 'employees.employeeID')
                         ->where('salarydetails.employeeID', '=', $this->employeeID)
                       ->orderBy('updatedOn', 'desc');

            return datatables()->eloquent($result)
            ->addColumn('edit', function ($row) {
                return '<a  class="btn btn-sm purple"  href="' . '' . '" ><i class="fa fa-edit"></i> SalaryHistory</a>';
            })
            ->escapeColumns(['edit'])
            ->make(false);
    }

     public function changeStatus(Request $request)
     {  
       $sidebar = ($request->read_data == 'true') ? '1' : '0';
        
        $filter = Auth::guard('employees')->user()->where('id',$request->sidebar_id)->update(['step1'=>$sidebar]);
            
        return Response::json([
        'success'                => true,
        'Verify_status'          => $request->read_data
        ]);
     }

     public function create(){

        $user = Auth::guard('employees')->user()->CompanyName;

        if($user == "TT"){

            $value = "techtonic.png";

        }elseif($user == "DB"){
            $value = "logo.png";
        }
        
        $data = array_merge(['value'=>$value,'user'=>$user]);
        
        return View::make('front.step1',$data,$this->data);
     }

     public function step2(){
    
      return View::make('front.step2',$this->data);
     }

     public function step3(){
    
       return View::make('front.step3',$this->data);
     }

     public function step4(){

        if(Auth::guard('employees')->user()){

            $this->employee = Employee::find(Auth::guard('employees')->user()->id);

            if($this->employee) { 
                return view ('front.step4',$this->data);
            } else {
                return \redirect()->back();
            }
        } else {
            return \redirect()->back();
        }
            
        }


    public function updatePersonal(Request $request){
        
        $this->employee = Employee::find(Auth::guard('employees')->user()->id);
        
        if($this->employee) {  
            $this->validate($request,[
               'fullName'         => 'required|min:2',
               'fatherName'       =>  'required|min:2',
               'alternate_mail'   => 'required',
               'emergency_phone'  => 'required',
               'mobileNumber'     => 'required',
               'localAddress'     => 'required',
               'permanentAddress' => 'required',
               'profileImage'     => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048'
            ]);
            if ($request->hasFile('profileImage')) {
                $attach = $request->file('profileImage');
                $name = time().'.'.$attach->getClientOriginalExtension();
                $destinationPath = public_path('/user-uploads/employee/');
                $attach->move($destinationPath, $name);
            }


            $this->employee->profileImage = $name;
            $this->employee->fullName = $request['fullName'];
            $this->employee->fatherName = $request['fatherName'];
            $this->employee->date_of_birth = $request['date_of_birth'];
            $this->employee->alternate_mail = $request['alternate_mail'];
            $this->employee->emergency_phone = $request['emergency_phone'];
            $this->employee->mobileNumber = $request['mobileNumber'];
            $this->employee->localAddress = $request['localAddress'];
            $this->employee->permanentAddress = $request['permanentAddress'];
            $this->employee->step4 =  $request['step4'];;
            $this->employee->save();
            $request->session()->flash('success','Your data upladed');
            return \redirect()->route('dashboard.index');
            }else{
                return \redirect()->back();
            } 
    }

    public function store(Request $request)
    {  

    $this->employeeID = Auth::guard('employees')->user()->employeeID;

     // UPLOAD THE DOCUMENTS  -----------------
     $this->validate($request,[
        'employeeID'                => 'required',
        'AadharCard_Proof'          => 'required',
        'higher_secondary_proof'    => 'required',
        'graduation_proof'          => 'required',
        ]);
        
     $documents = ['AadharCard_Proof','higher_secondary_proof','graduation_proof'];

     foreach ($documents as $document) {
         if ($request->hasFile($document)) {
             $file = new Files();
             $filename = $file->upload($request->file($document), 'employee_documents/' . $document, null, null, false); 
             $documents = Employee_document::create([
                'employeeID' => $this->employeeID,           
                'fileName'   => $filename,
                'type'       => $document,
            ]);  
        }   
    }
                
    $documents->save();

    $this->employee = Employee::find(Auth::guard('employees')->user()->id);

    if($this->employee) {  
        $this->employee->step2 = 1;
        $this->employee->save();
    }

    return redirect()->route('front.step3'); 
 }

    public function storeBankDetails(Request $request)
    {  
    
    $this->employeeID = Auth::guard('employees')->user()->employeeID;
  
    $this->validate($request,[
        'employeeID'       => 'required',
        'accountName'      => 'required',
        'accountNumber'    => 'required',
        'bank'             => 'required',
        'ifsc'             => 'required',
        ]);
    $users = Bank_detail::create([
        'employeeID'           =>  $this->employeeID,
        'accountName'          => $request->accountName,
        'accountNumber'        => $request->accountNumber,
        'bank'                 => $request->bank,
        'pan'                  => $request->pan,
        'ifsc'                 => $request->ifsc,
        'step3'                => $request->step3,
    ]);
    
    $users->save(); 

    $this->employee = Employee::find(Auth::guard('employees')->user()->id);

    if($this->employee) {  
        $this->employee->step3 = $request->step3;
        $this->employee->save();
    }

    return redirect()->route('front.step4'); 
    }


    public function index()
    {

        if(Auth::guard('employees')->user()->step1 == 0){
        $this->homeActive = 'active';
        $this->noticeboards = Noticeboard::where('status', '=', 'active')->orderBy('created_at', 'DESC')->get();
        $this->userAwards = user()->getAwards;
        $this->holiday_color = ['info', 'error', 'success', 'pending', ''];
        $this->holiday_font_color = ['blue', 'red', 'green', 'yellow', 'dark'];
        return redirect()->route('front.step1');
    }  elseif(Auth::guard('employees')->user()->step1 == 1 && Auth::guard('employees')->user()->step2 == 0){
        $this->homeActive = 'active';
        $this->noticeboards = Noticeboard::where('status', '=', 'active')->orderBy('created_at', 'DESC')->get();
        $this->userAwards = user()->getAwards;
        $this->holiday_color = ['info', 'error', 'success', 'pending', ''];
        $this->holiday_font_color = ['blue', 'red', 'green', 'yellow', 'dark'];
        return redirect()->route('front.step2');
    }  elseif(Auth::guard('employees')->user()->step1 == 1 && Auth::guard('employees')->user()->step2 == 1 && Auth::guard('employees')->user()->step3 == 0){
        $this->homeActive = 'active';
        $this->noticeboards = Noticeboard::where('status', '=', 'active')->orderBy('created_at', 'DESC')->get();
        $this->userAwards = user()->getAwards;
        $this->holiday_color = ['info', 'error', 'success', 'pending', ''];
        $this->holiday_font_color = ['blue', 'red', 'green', 'yellow', 'dark'];
        return redirect()->route('front.step3');
    }  elseif(Auth::guard('employees')->user()->step1 == 1 && Auth::guard('employees')->user()->step2 == 1 && Auth::guard('employees')->user()->step3 == 1 && Auth::guard('employees')->user()->step4 == 0){
        $this->homeActive = 'active';
        $this->noticeboards = Noticeboard::where('status', '=', 'active')->orderBy('created_at', 'DESC')->get();
        $this->userAwards = user()->getAwards;
        $this->holiday_color = ['info', 'error', 'success', 'pending', ''];
        $this->holiday_font_color = ['blue', 'red', 'green', 'yellow', 'dark'];
        return redirect()->route('front.step4');
    }else{
        $this->homeActive = 'active';
        $this->noticeboards = Noticeboard::where('status', '=', 'active')->orderBy('created_at', 'DESC')->get();
        $this->userAwards = user()->getAwards;
        $this->holiday_color = ['info', 'error', 'success', 'pending', ''];
        $this->holiday_font_color = ['blue', 'red', 'green', 'yellow', 'dark'];
        return View::make('front.employeeDashboard', $this->data);
     }
    }

    // Show leave Page

    /**
     * @return \Illuminate\Contracts\View\View
     */
    public function leave()
    {
        $this->leaveActive = 'active';

        $this->attendance = Attendance::where('employeeID', '=', $this->employeeID)->get();

        return View::make('front.leave', $this->data);
    }

    public function salary()
    {

        $this->salary = Salary::where('employeeID', '=', $this->employeeID)->get();

        return View::make('front.salary', $this->data);
    }

    public function viewHoliday(Request $request)
    {
        $this->holidays = Holiday::orderBy('date', 'ASC')->get();;
        $this->holidayActive = 'active';
        $hol = [];

        $year = Carbon::now()->format('Y');
        $dateArr = $this->getDateForSpecificDayBetweenDates($year . '-01-01', $year . '-12-31', 0);
        $this->number_of_sundays = count($dateArr);

        $this->holidays_in_db = count($this->holidays);

        foreach ($this->holidays as $holiday) {
            $hol[date('F', strtotime($holiday->date))]['id'][] = $holiday->id;
            $hol[date('F', strtotime($holiday->date))]['date'][] = date('d F Y', strtotime($holiday->date));
            $hol[date('F', strtotime($holiday->date))]['ocassion'][] = $holiday->occassion;
            $hol[date('F', strtotime($holiday->date))]['day'][] = date('D', strtotime($holiday->date));
        }

        $this->holidaysArray = $hol;

        return View::make('front.viewHoliday', $this->data);
    }

    public function salaryDetails()
    {

        $this->salaryDetails = SalaryDetails::where('employeeID', '=', $this->employeeID)->get();

        return View::make('front.salaryDetails', $this->data);
    }


    public function policyView()
    {
        $this->result = Policy::select('title','document','company')->get();
        
        return view('front.policy',$this->data);

    }

    /**
     * @param $id
     * @return \Illuminate\Http\JsonResponse
     */
    public function notice_ajax($id)
    {
        $notice = Noticeboard::find($id);
        $output['title'] = $notice->title;
        $output['description'] = $notice->description;

        return Response::json($output, 200);
    }

    // Submitting the leave request from Employee

    /**
     * @param LeaveStoreRequest $request
     * @return array
     */
    public function leave_store(LeaveStoreRequest $request)
    {
        foreach ($request->date as $index => $value) {

            if (empty($value)) continue;
            try {

                Attendance::create([
                    'employeeID' => $this->employeeID,
                    'date' => date('Y-m-d', strtotime($value)),
                    'status' => 'absent',
                    'leaveType' => $request->leaveType[$index],
                    'halfDayType' => ($request->leaveType[$index] == 'half day') ? $request->halfleaveType[$index] : null,
                    'reason' => $request->reason[$index],
                    'application_status' => 'pending',
                    'applied_on' => date('Y-m-d', time())
                ]);

                $dates[$index] = date('d-M-Y', strtotime($value));
                $leaveType[$index] = $request->leaveType[$index];
                $reason[$index] = $request->reason[$index];

            } catch (\Exception $e) {

                return Reply::error('<strong>Error!</strong> You have already applied leave for the particular date');
            }

        }

        // Send email to all admins
        $admins = Admin::select('id', 'email')->get();

        foreach ($admins as $admin) {
            // TODO::mail implementation
            event(new LeaveRequestToAdminEvent($admin, $this->setting->website, $dates, $leaveType, $reason));
        }

        Session::flash('success_leave', '<strong>Success!</strong> Leave request is send to the HR Manger.You will be notified soon.');
        return Reply::redirect(route('front.leave'), '<strong>Success!</strong> Leave request is send to the HR Manger.You will be notified soon.');

    }

    public function halfday_store(Request $request)
    {
        foreach ($request->date as $index => $value) {

            if (empty($value)) continue;
            try {

                Attendance::create([
                    'employeeID' => $this->employeeID,
                    'date' => date('Y-m-d', strtotime($value)),
                    'status' => 'half day',
                    'leaveType' => $request->leaveType[$index],
                    'halfDayType' => ($request->leaveType[$index] == 'half day') ? $request->halfleaveType[$index] : null,
                    'reason' => $request->reason[$index],
                    'application_status' => 'pending',
                    'applied_on' => date('Y-m-d', time())
                ]);

                $dates[$index] = date('d-M-Y', strtotime($value));
                $leaveType[$index] = $request->leaveType[$index];
                $reason[$index] = $request->reason[$index];

            } catch (\Exception $e) {

                return Reply::error('<strong>Error!</strong> You have already applied leave for the particular date');
            }

        }

        // Send email to all admins
        $admins = Admin::select('id', 'email')->get();

        foreach ($admins as $admin) {
            // TODO::mail implementation
            event(new LeaveRequestToAdminEvent($admin, $this->setting->website, $dates, $leaveType, $reason));
        }

        Session::flash('success_leave', '<strong>Success!</strong> Leave request is send to the HR Manger.You will be notified soon.');
        return Reply::redirect(route('front.leave'), '<strong>Success!</strong> Leave request is send to the HR Manger.You will be notified soon.');

    }

    public function ajaxSalary()
    {

        $result = Salary::select('employees.fullName','employees.joiningDate','salary.salary')
                          ->join('employees', 'salary.employeeID', '=', 'employees.employeeID')
                         ->where('salary.employeeID', '=', $this->employeeID)
                       ->orderBy('salary', 'desc');

            return datatables()->eloquent($result)
                ->editColumn('joiningDate', function ($row) {
                    return date('d-M-Y', strtotime($row->joiningDate));
                })
            ->addColumn('edit', function ($row) {
                return '<a  class="btn btn-sm purple"  href="' . route('front.salaryDetails') . '" ><i class="fa fa-edit"></i> SalaryHistory</a>';
            })
            ->escapeColumns(['edit'])
            ->make(false);
    }
    

    /**
     * @return \Illuminate\Http\JsonResponse
     */
    public function ajaxApplications()
    {

        $result = Attendance::select('id', 'date', 'leaveType', 'reason', 'applied_on', 'application_status', 'halfDayType')
            ->where('employeeID', '=', $this->employeeID)
            ->whereNotNull('application_status')
            ->orderBy('applied_on', 'desc');

        return datatables()->eloquent($result)
            ->editColumn('date', function ($row) {
                return date('d-M-Y', strtotime($row->date));
            })
            ->editColumn('applied_on', function ($row) {
                return date('d-M-Y', strtotime($row->applied_on));
            })
            ->editColumn('leaveType', function ($row) {
                $leave = ($row->leaveType == 'half day') ? $row->leaveType . '-' . $row->halfDayType : $row->leaveType;
                return $leave;
            })
            ->editColumn('reason', function ($row) {
                return strip_tags(\Illuminate\Support\Str::limit($row->reason, 50));

            })
            ->editColumn('application_status', function ($row) {
                $color = [
                    'pending' => 'warning',
                    'approved' => 'success',
                    'rejected' => 'danger'
                ];

                return '<span class="label label-' . $color[$row->application_status] . '">' . $row->application_status . '</span>';
            })
            ->addColumn('edit', function ($row) {
                return '<button  class="btn-u btn-u-blue" data-toggle="modal" data-target=".show_notice" onclick="show_application(' . $row->id . ');return false;" ><i class="fa fa-eye"></i> View</button>';
            })
            ->escapeColumns(['edit', 'application_status'])
            ->removeColumn('halfDayType')
            ->make(false);
    }

    public function changePasswordModal()
    {
        return View::make('front.change_password_modal', $this->data);
    }

    public function change_password(ChangePasswordRequest $request)
    {
        $employee = Auth::guard('employees')->user();
        $employee->password = $request->password;
        $employee->save();

        event(new ChangePasswordEvent($employee));

        return Reply::success('Password changed successfully');


    }

    /**
     * @param $id
     * @return \Illuminate\Contracts\View\View
     */
    public function show()
    {
        return View::make('front.MarkAttendance', $this->data);
    }

    public function storeAttendance(Request $request)
    {  

        $user = Attendance::firstOrCreate([
        'employeeID' =>  $this->employeeID,
        'date'       =>  $request->date,
        'status'     => 'present',
        'applied_on' => date('Y-m-d', time()),
    ]); 
        $user -> save();
    
    return redirect()->back()->with('success','Attendance Mark Successfully!');

    }


    public function getDateForSpecificDayBetweenDates($startDate, $endDate, $weekdayNumber)
    {
        $startDate = strtotime($startDate);
        $endDate = strtotime($endDate);

        $dateArr = [];

        do {
            if (date('w', $startDate) != $weekdayNumber) {
                $startDate += (24 * 3600); // add 1 day
            }
        } while (date('w', $startDate) != $weekdayNumber);


        while ($startDate <= $endDate) {
            $dateArr[] = date('Y-m-d', $startDate);
            $startDate += (7 * 24 * 3600); // add 7 days
        }

        return ($dateArr);
    }

}
